#!/usr/bin/perl

# obmenu-generator - schema file

=for comment

    item:      add an item inside the menu               {item => ["command", "label", "icon"]},
    cat:       add a category inside the menu             {cat => ["name", "label", "icon"]},
    sep:       horizontal line separator                  {sep => undef}, {sep => "label"},
    pipe:      a pipe menu entry                         {pipe => ["command", "label", "icon"]},
    file:      include the content of an XML file        {file => "/path/to/file.xml"},
    raw:       any XML data supported by Openbox          {raw => q(...)},
    beg:       begin of a category                        {beg => ["name", "icon"]},
    end:       end of a category                          {end => undef},
    obgenmenu: generic menu settings                {obgenmenu => ["label", "icon"]},
    exit:      default "Exit" action                     {exit => ["label", "icon"]},

=cut


# NOTE:
#    * Keys and values are case sensitive. Keep all keys lowercase.
#    * ICON can be a either a direct path to an icon or a valid icon name
#    * Category names are case insensitive. (X-XFCE and x_xfce are equivalent)

require "$ENV{HOME}/.config/obmenu-generator/config.pl";

## Text editor
my $editor = $CONFIG->{editor};


our $SCHEMA = [

    #          COMMAND                 LABEL              ICON
    {item => ['xfce4-terminal',            'Terminal',     '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['xfce4-terminal --command "sudo bash /opt/emperor-os-updater/update.sh" --geometry=400x300 -T "type root user"',      'Update Emperor-os',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    
    {item => ['rofi -modi drun -lines 12 -padding 18 -width 60 -location 0  -show drun',            'Run App',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['thunar',       'File Manager', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['pkexec thunar',       'FileManager As Root', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['firefox www.emperor-os.com', 'Web Browser',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['xfce4-taskmanager',       'Task Manager', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['parole',       'Media Player', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['okular',       'Document Viewer', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['hardinfo',       'System Informations', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['engrampa',       'Archive Manager', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['pkexec synaptic',      'Package Manager',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['xfce4-terminal --command "sudo lxrandr" --geometry=40x4 -T "Open it as  root user"',      'Change Resolution',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['xfce4-terminal --command "lxappearance" --geometry=40x4 -T "Open it as  root user"',      'Look and Feel',  '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['pkexec poweroff',       'Shutdown', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
    {item => ['pkexec reboot',       'Restart', '/usr/share/backgrounds/Emperor-Icons/32x32.png']},
   


#category    #name in menu
    {sep => 'Emperor-OS'},
    
    {beg => ['development',  '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
    

		{beg => ['Tutorial-help', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		{cat => ['OnlineEducation','OnlineEducation', 'applications-development']},
		{cat => ['cheatsheet', 'Language Cheat Sheets', 'applications-development']},
		{end => undef},


		{beg => ['Low Level', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		{cat => ['debug','debug', 'applications-development']},
		{cat => ['reversing', 'Reverse engineering', 'applications-development']},
		{end => undef},
		
		{beg => ['Embedded-IOT', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		{cat => ['IOT','Embedded-IOT', 'applications-development']},
		{cat => ['AVR', 'AVR', 'applications-development']},
		{end => undef},
		
		{cat => ['HDL','Hardware description languages', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},		
		{cat => ['UXUI', 'UX/UI Design Tools', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},	
		{cat => ['GUI','GUI Builder', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		{cat => ['model','Modeling Languages', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		
				
		{beg => ['Desktop Development', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},
		{cat => ['IDE','DE Tools', 'applications-development']},
		{cat => ['editor', 'Editor Tools', 'applications-development']},
		{cat => ['Eclipse', 'Eclipse Installer', 'applications-development']},
		{end => undef},
				
		{cat => ['DB', 'Database Tools', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['webdev', 'FullStack Web Development', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['SEO', 'Search Engine Optimization(SEO)', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['mobile', 'Mobile Development', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['Games', 'Game Development', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['MVC', 'IT AutomationSystem', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['Java', 'Java Technologies', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['bigdata', 'Big Data-Machine Learning', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['quantum', 'Quantum programming', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['kids', 'Kids Coding Languages', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['microsoft', 'Microsoft Technologies', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['framework', 'Frameworks-Libraries', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		{cat => ['Development', 'Other Development', '/usr/share/backgrounds/Emperor-Icons/132x32.png']},			
		
		
    {end => undef},


 




 {sep => 'Control Center'},
    
    {beg => ['Control Center',  '/home/user/.config/obmenu-generator/icons/c06402096ef5750b71486887f97da498.png']},
    
{cat => ['personal', 'Personal', '/home/user/.config/obmenu-generator/icons/0ae0c2941d429f0f86b4cdf86eaa80bb.png']},
{cat => ['lookandfeel', 'lookandfeel', '/home/user/.config/obmenu-generator/icons/8b0ee5d44d7ca7db093ab5abf2726972.png']},
{cat => ['launchers', 'launchersdocks', '/home/user/.config/obmenu-generator/icons/6471a978a1df59e1705c576a857950a4.png']},
{cat => ['appsettings', 'ApplicationSettings', '/home/user/.config/obmenu-generator/icons/2ea46923270fcf8b7d14ad46b1365e50.png']},
{cat => ['nwconfig', 'Network Config/Analysis', '/home/user/.config/obmenu-generator/icons/b951b4024dfefa18bfc7c651d2769550.png']},
{cat => ['print', 'ScanPrint', '/home/user/.config/obmenu-generator/icons/3f78bf01104828fbe7ce274b3deaeb96.png']},
{cat => ['Hardware', 'Hardware', '/home/user/.config/obmenu-generator/icons/b3de8731da29d2d32c2c17f5c48b64f3.png']},
{cat => ['System', 'Systems', '/home/user/.config/obmenu-generator/icons/8bf1d3819e5c0e2623835f025da780f5.png']},

{cat => ['DiscBurning', 'DVD-Disk-USB', '/home/user/.config/obmenu-generator/icons/1a9a17fdfb39d8b4ce6cae00f3cad9fe.png']},
{cat => ['display', 'Display', '/home/user/.config/obmenu-generator/icons/6e9df328a6d88decc9fb89f6f5beb229.png']},
{cat => ['backup', 'Backup', '/home/user/.config/obmenu-generator/icons/7faa341faab0b2e7de817eb3b783f6d1.png']},
{cat => ['security', 'SecurityPrivacy', '/home/user/.config/obmenu-generator/icons/796dd9feaa60b81eafc7b45eea55e521.png']},
{cat => ['tune', 'Tuning/Kernel', '/home/user/.config/obmenu-generator/icons/37f4c7b845715a4273a4910dca1e01b0.png']},


	
    {end => undef},





  #tools section ------------------------------------------======================================
    {sep => 'Other Tools'},
    
    #{cat => ['other',       'Extra Dev Tools',       'applications-other']},
    {cat => ['education',   'Education',   'applications-science']},
    {cat => ['game',        'Games',       'applications-games']},
    {cat => ['graphics',    'Graphics',    'applications-graphics']},
    {cat => ['audiovideo',  'Multimedia',  '/home/user/.config/obmenu-generator/icons/1ce5b87a98076c72630058cdd59e646a.png']},
    {cat => ['network',     'Network',     'applications-internet']},
    {cat => ['utility',     'Accessories', 'applications-utilities']},

    {cat => ['office',      'Office',      'applications-office']},
    {cat => ['settings',    'Settings',    'applications-accessories']},
    {cat => ['system',      'System',      'applications-system']},

    #             LABEL          ICON
    #{beg => ['My category',  'cat-icon']},
    #          ... some items ...
    #{end => undef},

    #            COMMAND     LABEL        ICON
    #{pipe => ['obbrowser', 'Disk', 'drive-harddisk']},

    ## Generic advanced settings
    #{sep       => undef},
    #{obgenmenu => ['Openbox Settings', 'applications-engineering']},
    #{sep       => undef},

    ## Custom advanced settings
    {sep => undef},
    {beg => ['Advanced Settings', 'applications-engineering']},

      # Configuration files
      {item => ["$editor ~/.conkyrc",              'Conky RC',    'text-x-generic']},
      {item => ["$editor ~/.config/tint2/tint2rc", 'Tint2 Panel', 'text-x-generic']},

      # obmenu-generator category
      {beg => ['Obmenu-Generator', 'accessories-text-editor']},
        {item => ["$editor ~/.config/obmenu-generator/schema.pl", 'Menu Schema', 'text-x-generic']},
        {item => ["$editor ~/.config/obmenu-generator/config.pl", 'Menu Config', 'text-x-generic']},

        {sep  => undef},
        {item => ['obmenu-generator -s -c',    'Generate a static menu',             'accessories-text-editor']},
        {item => ['obmenu-generator -s -i -c', 'Generate a static menu with icons',  'accessories-text-editor']},
        {sep  => undef},
        {item => ['obmenu-generator -p',       'Generate a dynamic menu',            'accessories-text-editor']},
        {item => ['obmenu-generator -p -i',    'Generate a dynamic menu with icons', 'accessories-text-editor']},
        {sep  => undef},

        {item => ['obmenu-generator -d', 'Refresh cache', 'view-refresh']},
      {end => undef},

      # Openbox category
      {beg => ['Openbox', 'openbox']},
        {item => ["$editor ~/.config/openbox/autostart", 'Openbox Autostart',   'text-x-generic']},
        {item => ["$editor ~/.config/openbox/rc.xml",    'Openbox RC',          'text-x-generic']},
        {item => ["$editor ~/.config/openbox/menu.xml",  'Openbox Menu',        'text-x-generic']},
        {item => ['openbox --reconfigure',               'Reconfigure Openbox', 'openbox']},
      {end => undef},
    {end => undef},

    {sep => undef},

    ## The xscreensaver lock command
    {item => ['xscreensaver-command -lock', 'Lock Screen', 'system-lock-screen']},

    ## This option uses the default Openbox's "Exit" action
#    {exit => ['Logout', 'application-exit']},
    {exit => ['Logout', 'lxde-logout']},

    ## This uses the 'oblogout' menu
    # {item => ['oblogout', 'lxde-logout', 'application-exit']},
]
